v1.0.5, 2014-05-16 - Freezer initial release. v1.0.6, 2014-05-24: -
Fixed error restore date is not provided. - Changed the datetime format
for --restore-from-date to "yyyy-mm-ddThh:mm:ss" - Created a FAQ.txt
file - Extended use case example in README.txt and Hacking.txt v1.0.7,
2014-06-05: - added multiprocessing support for backup and restore
